@@ -29,13 +29,13 @@ register_s3_method <- function(pkg, generic, class, fun = NULL) {
     register_s3_method("sandwich", "estfun", "rsmodel")
     register_s3_method("sandwich", "estfun", "pcmodel")
     register_s3_method("sandwich", "estfun", "gpcmodel")
-    register_s3_method("sandwich", "estfun", "plmodel")
+    register_s3_method("sandwich", "estfun", "nplmodel")
     register_s3_method("sandwich", "estfun", "mptmodel")
     register_s3_method("sandwich", "bread",  "raschmodel")
     register_s3_method("sandwich", "bread",  "rsmodel")
     register_s3_method("sandwich", "bread",  "pcmodel")
     register_s3_method("sandwich", "bread",  "gpcmodel")
-    register_s3_method("sandwich", "bread",  "plmodel")
+    register_s3_method("sandwich", "bread",  "nplmodel")
   }
   invisible()
 }
